%{?_compat_el5_build}

%{!?scl:%global scl autotools-latest}

%global gcc_version  %(gcc -dumpversion || echo "666")

%{?scl:%scl_package libtool}

Summary: The GNU Portable Library Tool
Name:    %{?scl_prefix}libtool
Version: 2.4.2
Release: 10%{?dist}
License: GPLv2+ and LGPLv2+ and GFDL
URL:     http://www.gnu.org/software/libtool/
Group:   Development/Tools

Source:  http://ftp.gnu.org/gnu/libtool/libtool-%{version}.tar.gz

# TODO: document reasons for this patch
# ~> downstream
Patch0:  libtool-2.4.2-rpath.patch

# Disable buggy tests for features we don't support.
# ~> downstream
Patch1:  libtool-2.4.2-disable-tests.patch

# Patch to use generated files by newer autotools (this allows us to build the
# package without running autoreconf during build)
Patch2:  libtool-2.4.2-autoreconfed.patch

# Run the 'tar --no-same-owner -xf' instead of 'tar -xf'
# ~> #740079
# ~> Downstream - tar is not used in upstream 'master' branch anymore, will be
#    fixed in next release.
Patch3:  libtool-2.4.2-tar-no-owner.patch

# /usr/bin/libtool includes paths within gcc's versioned directories
# Libtool must be rebuilt whenever a new upstream gcc is built
Requires: gcc = %{gcc_version}
Requires: %{scl_prefix}autoconf, %{scl_prefix}automake, sed, tar, findutils
Requires(post):  /sbin/install-info
Requires(preun): /sbin/install-info

BuildRequires: help2man
BuildRequires: texinfo

%{?scl:
BuildRequires: scl-utils-build
Requires:%scl_runtime
}

%if ! 0%{?buildroot:1}
# HACK!  This should be truth only for RHEL5, so benefit from
# this %%if for defining (otherwise undefined) macro for this platform.
%global rhel 5
BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%endif

# make sure we can configure all supported langs
BuildRequires: libstdc++-devel, gcc-gfortran


%description
GNU Libtool is a set of shell scripts which automatically configure UNIX and
UNIX-like systems to generically build shared libraries. Libtool provides a
consistent, portable interface which simplifies the process of using shared
libraries.

If you are developing programs which will use shared libraries, but do not use
the rest of the GNU Autotools (such as GNU Autoconf and GNU Automake), you
should install the libtool package.

The libtool package also includes all files needed to integrate the GNU
Portable Library Tool (libtool) and the GNU Libtool Dynamic Module Loader
(ltdl) into a package built using the GNU Autotools (including GNU Autoconf
and GNU Automake).


%package ltdl
Summary:  Runtime libraries for GNU Libtool Dynamic Module Loader
Group:    System Environment/Libraries
Provides: %{name}-libs = %{version}-%{release}
License:  LGPLv2+
Requires(post):  /sbin/ldconfig
Requires(postun):  /sbin/ldconfig
%{?scl:Requires:%scl_runtime}

%description ltdl
The libtool-ltdl package contains the GNU Libtool Dynamic Module Loader, a
library that provides a consistent, portable interface which simplifies the
process of using dynamic modules.

These runtime libraries are needed by programs that link directly to the
system-installed ltdl libraries; they are not needed by software built using
the rest of the GNU Autotools (including GNU Autoconf and GNU Automake).


%package ltdl-devel
Summary: Tools needed for development using the GNU Libtool Dynamic Module Loader
Group:    Development/Libraries
Requires: %{name}-ltdl = %{version}-%{release}
License:  LGPLv2+
%{?scl:Requires:%scl_runtime}

%description ltdl-devel
Static libraries and header files for development with ltdl.


%prep
%setup -q -n libtool-%version

%patch0 -p1 -b .rpath
%patch1 -p1 -b .disable-test
%patch2 -p1 -b .autoreconfed
%patch3 -p1 -b .nosameowner

# to use this, we should 100% *know* what the patches do
find -exec touch --date=`date -I` {} +


%build
export CC=gcc
export CXX=g++
export F77=gfortran
export CFLAGS="$RPM_OPT_FLAGS -fPIC"

%configure  --prefix=%{_prefix}                 \
            --exec-prefix=%{_prefix}            \
            --bindir=%{_bindir}                 \
            --sbindir=%{_sbindir}               \
            --sysconfdir=%{_sysconfdir}         \
            --datadir=%{_datadir}               \
            --includedir=%{_includedir}         \
            --libdir=%{_libdir}                 \
            --libexecdir=%{_libexecdir}         \
            --localstatedir=%{_localstatedir}   \
            --mandir=%{_mandir}                 \
            --infodir=%{_infodir}               \
            --host= --build= --target=

make %{?_smp_mflags}

for i in ChangeLog.1997 ChangeLog.1998 ChangeLog.1999 ChangeLog.2002; do
  iconv -f ISO_8859-15 -t UTF8 $i > $i.tmp
  mv -f $i.tmp $i
done


%check
# make check VERBOSE=yes


%install
%if 0%{?rhel} == 5
rm -rf %{builroot}
%endif
make install DESTDIR=%{buildroot}

# info's TOP dir (by default owned by info)
rm -f %{buildroot}%{_infodir}/dir

# *.la *.a files generated by libtool shouldn't be distributed (and the
# `./configure --disable-static' breaks testsuite)
rm -f %{buildroot}%{_libdir}/libltdl.{a,la}


%post
/sbin/install-info %{_infodir}/libtool.info.gz %{_infodir}/dir || :


%post ltdl -p /sbin/ldconfig


%preun
if [ "$1" = 0 ]; then
   /sbin/install-info --delete %{_infodir}/libtool.info.gz %{_infodir}/dir || :
fi


%postun ltdl -p /sbin/ldconfig


%files
%doc AUTHORS COPYING NEWS README THANKS TODO ChangeLog*
%{_infodir}/libtool.info*.gz
%{_mandir}/man1/libtool.1*
%{_mandir}/man1/libtoolize.1*
%{_bindir}/libtool
%{_bindir}/libtoolize
%{_datadir}/aclocal/*.m4
%exclude %{_datadir}/libtool/libltdl
%{_datadir}/libtool

%files ltdl
%doc libltdl/COPYING.LIB
%{_libdir}/libltdl.so.*

%files ltdl-devel
%doc libltdl/README
%{_datadir}/libtool/libltdl
%{_includedir}/ltdl.h
%{_includedir}/libltdl
# .so files without version must be in -devel subpackage
%{_libdir}/libltdl.so

%changelog
* Wed Aug 12 2015 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-10
- help2man BR

* Wed Aug 12 2015 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-9
- use _compat_el5_build only if defined (rhbz#1252751)

* Sat Feb 07 2015 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-8
- rebuild for new gcc rawhide

* Fri Dec 19 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-7
- rebuild for the new gcc

* Sun Jul 13 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-6
- rebuild for new gcc in F19, second try

* Fri Jul 11 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-5
- rebuild for new gcc in F19

* Sat Jun 28 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-4
- rebuild for new gcc 4.8.3
- gcc-java removed from Fedora completely (#1106080)

* Thu May 29 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-3
- release bump for %%_compat_el5_build

* Tue Mar 25 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-2
- RHEL5 fixes

* Fri Mar 21 2014 Pavel Raiskup <praiskup@redhat.com> - 2.4.2-1
- copy SCL-ized spec from autotools-git
